@@ -1,6 +1,6 @@
 #
 # -*- Perl -*-
-# $Id: pdf.pl,v 1.22 2001/01/04 01:57:58 baba Exp $
+# $Id: pdf.pl,v 1.22.4.6 2002/07/29 08:16:39 knok Exp $
 # Copyright (C) 1997-2000 Satoru Takabayashi ,
 #               1999 NOKUBI Takatsugu All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
@@ -29,6 +29,9 @@ require 'util.pl';
 require 'gfilter.pl';
 
 my $pdfconvpath = undef;
+my $pdfinfopath = undef;
+my $pdfconvver = 0;
+my $pdfconvarg = '';
 
 sub mediatype() {
     return ('application/pdf');
@@ -36,7 +39,21 @@ sub mediatype() {
 
 sub status() {
     $pdfconvpath = util::checkcmd('pdftotext');
-    return 'yes' if (defined $pdfconvpath);
+    $pdfinfopath = util::checkcmd('pdfinfo');
+    if (defined $pdfconvpath) {
+	my $ret = `$pdfconvpath 2>&1`;
+	if ($ret =~ /^pdftotext\s+version\s+([0-9]+\.[0-9]+)/) {
+	    $pdfconvver = $1;
+	}
+	if (util::islang("ja")) {
+	    if ($pdfconvver >= 1.00) {
+		$pdfconvarg = '-enc EUC-JP';
+	    } else {
+		$pdfconvarg = '-eucjp';
+	    }
+	}
+	return 'yes';
+    }
     return 'no';
 }
 
@@ -70,10 +87,10 @@ sub filter ($$$$$) {
 
     if (util::islang("ja")) {
 	util::vprint("Processing pdf file ... (using  '$pdfconvpath' in Japanese mode)\n");
-	system("$pdfconvpath -q -eucjp $tmpfile $tmpfile2");
+	system("$pdfconvpath -q $pdfconvarg -raw $tmpfile $tmpfile2");
     } else {
 	util::vprint("Processing pdf file ... (using  '$pdfconvpath')\n");
-	system("$pdfconvpath -q $tmpfile $tmpfile2");
+	system("$pdfconvpath -q -raw $tmpfile $tmpfile2");
     }
     unless (-e $tmpfile2) {
 	unlink $tmpfile;
@@ -84,7 +101,6 @@ sub filter ($$$$$) {
     $fh = util::efopen("< $tmpfile2");
     $$cont = util::readfile($fh);
     undef $fh;
-    unlink $tmpfile;
     unlink $tmpfile2;
 
     gfilter::line_adjust_filter($cont);
@@ -94,6 +110,28 @@ sub filter ($$$$$) {
 	unless $fields->{'title'};
     gfilter::show_filter_debug_info($cont, $weighted_str,
 			   $fields, $headings);
+
+    if (defined $pdfinfopath) {
+	my $tmpfile3 = util::tmpnam('NMZ.pdf3');
+#	system("$pdfinfopath $tmpfile > $tmpfile3");
+	open(SAVEOUT, ">&STDOUT");
+	open(STDOUT, ">$tmpfile3");
+	system("$pdfinfopath $tmpfile");
+	open(STDOUT, ">&SAVEOUT");
+	my $fh = util::efopen("< $tmpfile3");
+	my $cont2 = util::readfile($fh);
+	undef $fh;
+	unlink($tmpfile3);
+	if ($cont2 =~ /Title: (.*)/) { # or /Subject: (.*)/
+	    $fields->{'title'} = $1;
+	}
+	if ($cont2 =~ /Author: (.*)/) {
+	    $fields->{'author'} = $1;
+	}
+    }
+
+    unlink $tmpfile;
+
     return undef;
 }
 
