@@ -2,7 +2,7 @@
  * 
  * cgi.c -
  * 
- * $Id: cgi.c,v 1.61.4.3 2001/09/02 07:13:38 rug Exp $
+ * $Id: cgi.c,v 1.61.4.10 2002/06/06 10:48:46 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -122,17 +122,20 @@ validate_idxname(const char * idxname)
 
     if (*idxname == '\0' || *idxname == '/' || (win32 && *idxname == '\\')) {
         printf("%s text/html" CRLF CRLF, MSG_MIME_HEADER);
-	printf("%s : ", idxname);
+	puts_entitize(idxname);
+	printf(" : ");
         printf(_("Invalid idxname."));
         exit(EXIT_FAILURE);
     }
     while (*idxname) {
         if (nmz_strprefixcasecmp("../", idxname) == 0 ||
 	    strcmp("..", idxname) == 0 ||
-            (win32 && nmz_strprefixcasecmp("..\\", idxname) == 0)) 
+            (win32 && nmz_strprefixcasecmp("..\\", idxname) == 0) || 
+            (win32 && nmz_strprefixcasecmp("..." , idxname) == 0)) 
         {
 	    printf("%s text/html" CRLF CRLF, MSG_MIME_HEADER);
-	    printf("%s : ", idxname);
+	    puts_entitize(idxname);
+	    printf(" : ");
             printf(_("Invalid idxname."));
             exit(EXIT_FAILURE);
         }
@@ -216,9 +219,7 @@ get_query_string(void)
 	 */
         contlen = strlen(query_string);
         if (contlen > CGI_QUERY_MAX) {
-	    printf("%s text/html" CRLF CRLF, MSG_MIME_HEADER);
-            printf(_("Too long QUERY_STRING"));
-            exit(EXIT_FAILURE);
+	    die("%s", _("Too long QUERY_STRING"));
         }
 	script_name = getenv("SCRIPT_NAME");
         if (script_name == NULL) {
@@ -258,6 +259,10 @@ get_cgi_vars(const char *querystring)
 	    break;
 	}
 	len = tmp - querystring;
+	if (len >= BUFSIZE) {
+	    len = BUFSIZE - 1;
+	    nmz_warn_printf("%s", "truncating a CGI paramater name.\n");
+	}
 	strncpy(name, querystring, len);
 	*(name + len) = '\0';
 	querystring += len;
@@ -268,6 +273,10 @@ get_cgi_vars(const char *querystring)
 	    tmp = querystring + strlen(querystring);  /* last point: '\0' */
 	}
 	len = tmp - querystring;
+	if (len >= BUFSIZE) {
+	    len = BUFSIZE - 1;
+	    nmz_warn_printf("%s", "truncating a CGI paramater value.\n");
+	}
 	strncpy(value, querystring, len);
 	*(value + len) = '\0';
 	nmz_decode_uri(value);
@@ -481,18 +490,21 @@ process_cgi_var_idxname(char *value, struct cgiarg *ca)
 
 	if ((x = (char *)strchr(pp, (int)','))) {
 	    *x = '\0';
-	    strcpy(name, pp);
+	    strncpy(name, pp, BUFSIZE);
+	    name[BUFSIZE - 1] = '\0';
 	    pp = x + 1;
 	} else {
-	    strcpy(name, pp);
+	    strncpy(name, pp, BUFSIZE);
+	    name[BUFSIZE - 1] = '\0';
 	    pp += strlen(pp);
 	}
 	validate_idxname(name);
 	remove_ending_slashes(name);
 
-	strcpy(tmp, nmz_get_defaultidx());
-	strcat(tmp, "/");
-	strcat(tmp, name);
+	strncpy(tmp, nmz_get_defaultidx(), BUFSIZE);
+	strncat(tmp, "/", BUFSIZE - strlen(tmp));
+	strncat(tmp, name, BUFSIZE - strlen(tmp));
+	tmp[BUFSIZE -1] = '\0';
 	if (nmz_add_index(tmp) != SUCCESS) {
 	    nmz_warn_printf("invalid idxname: %s", name);
 	}
