@@ -2,7 +2,7 @@
  * 
  * namazu.c - search client of Namazu
  *
- * $Id: namazu-cmd.c,v 1.17 2001/01/20 03:34:50 baba Exp $
+ * $Id: namazu-cmd.c,v 1.17.4.3 2002/01/11 05:16:47 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -32,8 +32,6 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <ctype.h>
-#include <string.h>
-#include <unistd.h>
 #include <sys/stat.h>
 #include <signal.h>
 #include <stdarg.h>
@@ -44,6 +42,21 @@
 #ifdef HAVE_SUPPORT_H
 #  include "support.h"
 #endif
+
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#else
+# ifdef _WIN32
+# include <io.h>
+# endif
+#endif
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include "namazu.h"
 #include "libnamazu.h"
 #include "getopt.h"
@@ -326,7 +339,7 @@ main(int argc, char **argv)
 	    return 1;
 	}
 
-        strcpy(query, argv[i++]);
+        strncpy(query, argv[i++], BUFSIZE - 1);
         if (i < argc) {
 	    int curidx = nmz_get_idxnum();
             for (curidx = 0; i < argc && curidx < INDEX_MAX; i++) {
