@@ -1,6 +1,6 @@
 /*
  * 
- * $Id: rcfile.c,v 1.31.4.1 2001/09/02 07:13:38 rug Exp $
+ * $Id: rcfile.c,v 1.31.4.3 2001/12/21 03:30:24 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -371,6 +371,7 @@ get_rc_arg(const char *line, char *arg)
     *arg = '\0';
     if (*line != '"') {
 	int n = strcspn(line, " \t");
+	if (n >= BUFSIZE) n = BUFSIZE - 1;
 	strncpy(arg, line, n);
 	arg[n] = '\0';     /* Hey, don't forget this after strncpy()! */
 	return n;
@@ -380,10 +381,12 @@ get_rc_arg(const char *line, char *arg)
 	n = 1;
 	do {
 	    int nn = strcspn(line, "\"\\");
+	    if (nn >= (BUFSIZE - strlen(arg))) nn = BUFSIZE - strlen(arg) - 1;
 	    strncat(arg, line, nn);
 	    n += nn;
 	    line += nn;
 	    arg[n] = '\0';
+	    if (n >= BUFSIZE) return n;
 	    if (*line == '\0') {  /* terminator not matched */
 		errmsg = _("can't find string terminator");
 		return 0;
@@ -412,10 +415,10 @@ replace_home(char *str)
 	char *home;
 	/* Checke a home directory */
 	if ((home = getenv("HOME")) != NULL) {
-	    strcpy(tmp, home);
-	    strcat(tmp, "/");
-	    strcat(tmp, str + strlen("~/"));
-	    strcpy(str, tmp);
+	    strncpy(tmp, home, BUFSIZE - 1);
+	    strncat(tmp, "/", BUFSIZE - strlen(tmp) - 1);
+	    strncat(tmp, str + strlen("~/"), BUFSIZE - strlen(tmp) - 1);
+	    strncpy(str, tmp, BUFSIZE - 1);
 	    return;
 	}
     }
@@ -504,6 +507,7 @@ get_rc_args(const char *line)
 	    errmsg = _("invalid directive name");
 	    return 0;
 	}
+	if (n >= BUFSIZE) n = BUFSIZE - 1;
 	strncpy(directive, line, n);
 	directive[n] = '\0';  /* Hey, don't forget this after strncpy()! */
 	list = add_strlist(list, directive);
@@ -659,7 +663,7 @@ load_rcfile(const char *fname)
 	return FAILURE;
     }
 
-    while (fgets(buf, BUFSIZE, fp) != NULL) {
+    while (fgets(buf, BUFSIZE - 1, fp) != NULL) {
 	int current_lineno = lineno;
 	
 	do {
@@ -669,7 +673,7 @@ load_rcfile(const char *fname)
 		int remaining;
 		
 		buf[strlen(buf) - 1] = '\0'; /* Remove ending \ */
-		remaining = BUFSIZE - strlen(buf);
+		remaining = BUFSIZE - strlen(buf) - 1;
 		if (fgets(buf + strlen(buf), remaining, fp) == NULL) {
 		    nmz_chomp(buf);
 		    break;
@@ -734,8 +738,9 @@ load_rcfiles(void)
 	    }
 	} else {
 	    char fname[BUFSIZE];
-	    strcpy(fname, namazurcdir);
-	    strcat(fname, "/namazurc");
+	    strncpy(fname, namazurcdir, BUFSIZE - 1);
+	    strncat(fname, "/namazurc",
+		    BUFSIZE - strlen(fname) - 1);
 	    /* 
 	 * Load the file only if it exists.
 	 */
@@ -754,8 +759,9 @@ load_rcfiles(void)
 	char *home = getenv("HOME");
 	if (home != NULL) {
 	    char fname[BUFSIZE];
-	    strcpy(fname, home);
-	    strcat(fname, "/.namazurc");
+	    strncpy(fname, home, BUFSIZE - 1);
+	    strncat(fname, "/.namazurc",
+		    BUFSIZE - strlen(fname) - 1);
 	    /* 
 	     * Load the file only if it exists.
 	     */
